#Topsis-Aditya-101903150
Multiple criteria decision making (MCDM) using TOPSIS

## Installation
```pip install topsis-ADITYA-101903150```

##Sample Use case
import topsis-ADITYA-10903150 as t
t.topsis("input.csv","1,2,1,2,3","+,+,-,+,-","output.csv")
